==> haskell-hs-bibutils-6.10.0.0-152-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-FliRwSXhIdKGqaW305smTO
key:                  hs-bibutils-6.10.0.0-FliRwSXhIdKGqaW305smTO
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  9c829fd74879f89dc2f6ad81e10b5900
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-FliRwSXhIdKGqaW305smTO
includes:             bibutils.h
depends:              base-4.16.4.0 syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.10.0.0-180.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-Esv0zpbuPvy6u0Z2fDZtgp
key:                  hs-bibutils-6.10.0.0-Esv0zpbuPvy6u0Z2fDZtgp
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  e663e6a7506c9db1749c010f190407c9
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-Esv0zpbuPvy6u0Z2fDZtgp
includes:             bibutils.h
depends:              base-4.17.2.1 syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
